# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/playurl/v1/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/playurl/v1/playurl.proto\x12\x17\x62ilibili.app.playurl.v1\"D\n\x02\x41\x42\x12/\n\x06glance\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.playurl.v1.Glance\x12\r\n\x05group\x18\x02 \x01(\x05\"m\n\x07\x41rcConf\x12\x12\n\nis_support\x18\x01 \x01(\x08\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12<\n\rextra_content\x18\x03 \x01(\x0b\x32%.bilibili.app.playurl.v1.ExtraContent\"$\n\x07\x43hronos\x12\x0b\n\x03md5\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\"\xc1\x01\n\tCloudConf\x12\x0c\n\x04show\x18\x01 \x01(\x08\x12\x34\n\tconf_type\x18\x02 \x01(\x0e\x32!.bilibili.app.playurl.v1.ConfType\x12\x38\n\x0b\x66ield_value\x18\x03 \x01(\x0b\x32#.bilibili.app.playurl.v1.FieldValue\x12\x36\n\nconf_value\x18\x04 \x01(\x0b\x32\".bilibili.app.playurl.v1.ConfValue\"B\n\tConfValue\x12\x14\n\nswitch_val\x18\x01 \x01(\x08H\x00\x12\x16\n\x0cselected_val\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"\x8e\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0f\n\x07\x62\x61seUrl\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x05 \x01(\r\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x12\n\nframe_rate\x18\x08 \x01(\t\"\xc8\x01\n\tDashVideo\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x12\n\nbackup_url\x18\x02 \x03(\t\x12\x11\n\tbandwidth\x18\x03 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x04 \x01(\r\x12\x0b\n\x03md5\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x0f\n\x07\x61udioId\x18\x07 \x01(\r\x12\x12\n\nno_rexcode\x18\x08 \x01(\x08\x12\x12\n\nframe_rate\x18\t \x01(\t\x12\r\n\x05width\x18\n \x01(\x05\x12\x0e\n\x06height\x18\x0b \x01(\x05\"\x9d\x01\n\tDolbyItem\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.bilibili.app.playurl.v1.DolbyItem.Type\x12\x30\n\x05\x61udio\x18\x02 \x01(\x0b\x32!.bilibili.app.playurl.v1.DashItem\"\'\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41TMOS\x10\x02\"6\n\x05\x45vent\x12-\n\x05shake\x18\x01 \x01(\x0b\x32\x1e.bilibili.app.playurl.v1.Shake\">\n\x0c\x45xtraContent\x12\x17\n\x0f\x64isabled_reason\x18\x01 \x01(\t\x12\x15\n\rdisabled_code\x18\x02 \x01(\x03\"\'\n\nFieldValue\x12\x10\n\x06switch\x18\x01 \x01(\x08H\x00\x42\x07\n\x05value\"\x8d\x01\n\x11\x46ormatDescription\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0fnew_description\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x05 \x01(\t\x12\x13\n\x0bsuperscript\x18\x06 \x01(\t\"<\n\x06Glance\x12\x11\n\tcan_watch\x18\x01 \x01(\x08\x12\r\n\x05times\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\"\xc9\r\n\x0fPlayAbilityConf\x12@\n\x14\x62\x61\x63kground_play_conf\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tflip_conf\x18\x02 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tcast_conf\x18\x03 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\rfeedback_conf\x18\x04 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\rsubtitle_conf\x18\x05 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12>\n\x12playback_rate_conf\x18\x06 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x38\n\x0ctime_up_conf\x18\x07 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12>\n\x12playback_mode_conf\x18\x08 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12;\n\x0fscale_mode_conf\x18\t \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tlike_conf\x18\n \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x38\n\x0c\x64islike_conf\x18\x0b \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tcoin_conf\x18\x0c \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\telec_conf\x18\r \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x36\n\nshare_conf\x18\x0e \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12<\n\x10screen_shot_conf\x18\x0f \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12<\n\x10lock_screen_conf\x18\x10 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12:\n\x0erecommend_conf\x18\x11 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12?\n\x13playback_speed_conf\x18\x12 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12;\n\x0f\x64\x65\x66inition_conf\x18\x13 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12;\n\x0fselections_conf\x18\x14 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x35\n\tnext_conf\x18\x15 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x38\n\x0c\x65\x64it_dm_conf\x18\x16 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12=\n\x11small_window_conf\x18\x17 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x36\n\nshake_conf\x18\x18 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\router_dm_conf\x18\x19 \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12:\n\x0einnerDmDisable\x18\x1a \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x39\n\rinner_dm_conf\x18\x1b \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12\x36\n\ndolby_conf\x18\x1c \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\x12=\n\x11\x63olor_filter_conf\x18\x1d \x01(\x0b\x32\".bilibili.app.playurl.v1.CloudConf\"\xcb\r\n\x0bPlayArcConf\x12>\n\x14\x62\x61\x63kground_play_conf\x18\x01 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tflip_conf\x18\x02 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tcast_conf\x18\x03 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rfeedback_conf\x18\x04 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rsubtitle_conf\x18\x05 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12<\n\x12playback_rate_conf\x18\x06 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x36\n\x0ctime_up_conf\x18\x07 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12<\n\x12playback_mode_conf\x18\x08 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x39\n\x0fscale_mode_conf\x18\t \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tlike_conf\x18\n \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x36\n\x0c\x64islike_conf\x18\x0b \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tcoin_conf\x18\x0c \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\telec_conf\x18\r \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x34\n\nshare_conf\x18\x0e \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12:\n\x10screen_shot_conf\x18\x0f \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12:\n\x10lock_screen_conf\x18\x10 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x38\n\x0erecommend_conf\x18\x11 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12=\n\x13playback_speed_conf\x18\x12 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x39\n\x0f\x64\x65\x66inition_conf\x18\x13 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x39\n\x0fselections_conf\x18\x14 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x33\n\tnext_conf\x18\x15 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x36\n\x0c\x65\x64it_dm_conf\x18\x16 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12;\n\x11small_window_conf\x18\x17 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x34\n\nshake_conf\x18\x18 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\router_dm_conf\x18\x19 \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rinner_dm_conf\x18\x1a \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x37\n\rpanorama_conf\x18\x1b \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12\x34\n\ndolby_conf\x18\x1c \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12?\n\x15screen_recording_conf\x18\x1d \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\x12;\n\x11\x63olor_filter_conf\x18\x1e \x01(\x0b\x32 .bilibili.app.playurl.v1.ArcConf\"\x13\n\x11PlayConfEditReply\"L\n\x0fPlayConfEditReq\x12\x39\n\tplay_conf\x18\x01 \x03(\x0b\x32&.bilibili.app.playurl.v1.PlayConfState\"L\n\rPlayConfReply\x12;\n\tplay_conf\x18\x01 \x01(\x0b\x32(.bilibili.app.playurl.v1.PlayAbilityConf\"\r\n\x0bPlayConfReq\"\xc5\x01\n\rPlayConfState\x12\x34\n\tconf_type\x18\x01 \x01(\x0e\x32!.bilibili.app.playurl.v1.ConfType\x12\x0c\n\x04show\x18\x02 \x01(\x08\x12\x38\n\x0b\x66ield_value\x18\x03 \x01(\x0b\x32#.bilibili.app.playurl.v1.FieldValue\x12\x36\n\nconf_value\x18\x04 \x01(\x0b\x32\".bilibili.app.playurl.v1.ConfValue\"\xc1\x03\n\x0cPlayURLReply\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12\r\n\x05\x66nver\x18\x05 \x01(\r\x12\r\n\x05\x66nval\x18\x06 \x01(\r\x12\x15\n\rvideo_project\x18\x07 \x01(\x08\x12\x32\n\x04\x64url\x18\x08 \x03(\x0b\x32$.bilibili.app.playurl.v1.ResponseUrl\x12\x33\n\x04\x64\x61sh\x18\t \x01(\x0b\x32%.bilibili.app.playurl.v1.ResponseDash\x12\x12\n\nno_rexcode\x18\n \x01(\x05\x12<\n\rupgrade_limit\x18\x0b \x01(\x0b\x32%.bilibili.app.playurl.v1.UpgradeLimit\x12\x43\n\x0fsupport_formats\x18\x0c \x03(\x0b\x32*.bilibili.app.playurl.v1.FormatDescription\x12\x30\n\x04type\x18\r \x01(\x0e\x32\".bilibili.app.playurl.v1.VideoType\"\xa8\x01\n\nPlayURLReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\"\x85\x03\n\rPlayViewReply\x12\x36\n\nvideo_info\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.VideoInfo\x12;\n\tplay_conf\x18\x02 \x01(\x0b\x32(.bilibili.app.playurl.v1.PlayAbilityConf\x12<\n\rupgrade_limit\x18\x03 \x01(\x0b\x32%.bilibili.app.playurl.v1.UpgradeLimit\x12\x31\n\x07\x63hronos\x18\x04 \x01(\x0b\x32 .bilibili.app.playurl.v1.Chronos\x12\x36\n\x08play_arc\x18\x05 \x01(\x0b\x32$.bilibili.app.playurl.v1.PlayArcConf\x12-\n\x05\x65vent\x18\x06 \x01(\x0b\x32\x1e.bilibili.app.playurl.v1.Event\x12\'\n\x02\x61\x62\x18\x07 \x01(\x0b\x32\x1b.bilibili.app.playurl.v1.AB\"\xcb\x02\n\x0bPlayViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12<\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32!.bilibili.app.playurl.v1.CodeType\x12\x33\n\x08\x62usiness\x18\r \x01(\x0e\x32!.bilibili.app.playurl.v1.Business\x12\x15\n\rvoice_balance\x18\x0e \x01(\x03\"F\n\x0cProjectReply\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.bilibili.app.playurl.v1.PlayURLReply\"\xcf\x01\n\nProjectReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x05\"r\n\x0cResponseDash\x12\x30\n\x05video\x18\x01 \x03(\x0b\x32!.bilibili.app.playurl.v1.DashItem\x12\x30\n\x05\x61udio\x18\x02 \x03(\x0b\x32!.bilibili.app.playurl.v1.DashItem\"h\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x12\n\nbackup_url\x18\x05 \x03(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\"E\n\x0cSegmentVideo\x12\x35\n\x07segment\x18\x01 \x03(\x0b\x32$.bilibili.app.playurl.v1.ResponseUrl\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xc7\x01\n\x06Stream\x12\x38\n\x0bstream_info\x18\x01 \x01(\x0b\x32#.bilibili.app.playurl.v1.StreamInfo\x12\x38\n\ndash_video\x18\x02 \x01(\x0b\x32\".bilibili.app.playurl.v1.DashVideoH\x00\x12>\n\rsegment_video\x18\x03 \x01(\x0b\x32%.bilibili.app.playurl.v1.SegmentVideoH\x00\x42\t\n\x07\x63ontent\"\xaa\x02\n\nStreamInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x65rr_code\x18\x04 \x01(\r\x12\x33\n\x05limit\x18\x05 \x01(\x0b\x32$.bilibili.app.playurl.v1.StreamLimit\x12\x10\n\x08need_vip\x18\x06 \x01(\x08\x12\x12\n\nneed_login\x18\x07 \x01(\x08\x12\x0e\n\x06intact\x18\x08 \x01(\x08\x12\x12\n\nno_rexcode\x18\t \x01(\x08\x12\x11\n\tattribute\x18\n \x01(\x03\x12\x17\n\x0fnew_description\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x0c \x01(\t\x12\x13\n\x0bsuperscript\x18\r \x01(\t\"6\n\x0bStreamLimit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\",\n\rUpgradeButton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"t\n\x0cUpgradeLimit\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x36\n\x06\x62utton\x18\x04 \x01(\x0b\x32&.bilibili.app.playurl.v1.UpgradeButton\"\xac\x02\n\tVideoInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12\x34\n\x0bstream_list\x18\x05 \x03(\x0b\x32\x1f.bilibili.app.playurl.v1.Stream\x12\x35\n\ndash_audio\x18\x06 \x03(\x0b\x32!.bilibili.app.playurl.v1.DashItem\x12\x31\n\x05\x64olby\x18\x07 \x01(\x0b\x32\".bilibili.app.playurl.v1.DolbyItem\x12\x33\n\x06volume\x18\x08 \x01(\x0b\x32#.bilibili.app.playurl.v1.VolumeInfo\"\xa3\x01\n\nVolumeInfo\x12\x12\n\nmeasured_i\x18\x01 \x01(\x01\x12\x14\n\x0cmeasured_lra\x18\x02 \x01(\x01\x12\x13\n\x0bmeasured_tp\x18\x03 \x01(\x01\x12\x1a\n\x12measured_threshold\x18\x04 \x01(\x01\x12\x15\n\rtarget_offset\x18\x05 \x01(\x01\x12\x10\n\x08target_i\x18\x06 \x01(\x01\x12\x11\n\ttarget_tp\x18\x07 \x01(\x01*\"\n\x08\x42usiness\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05STORY\x10\x01*0\n\x08\x43odeType\x12\n\n\x06NOCODE\x10\x00\x12\x0b\n\x07\x43ODE264\x10\x01\x12\x0b\n\x07\x43ODE265\x10\x02*\xaf\x03\n\x08\x43onfType\x12\n\n\x06NoType\x10\x00\x12\x0c\n\x08\x46LIPCONF\x10\x01\x12\x0c\n\x08\x43\x41STCONF\x10\x02\x12\x0c\n\x08\x46\x45\x45\x44\x42\x41\x43K\x10\x03\x12\x0c\n\x08SUBTITLE\x10\x04\x12\x10\n\x0cPLAYBACKRATE\x10\x05\x12\n\n\x06TIMEUP\x10\x06\x12\x10\n\x0cPLAYBACKMODE\x10\x07\x12\r\n\tSCALEMODE\x10\x08\x12\x12\n\x0e\x42\x41\x43KGROUNDPLAY\x10\t\x12\x08\n\x04LIKE\x10\n\x12\x0b\n\x07\x44ISLIKE\x10\x0b\x12\x08\n\x04\x43OIN\x10\x0c\x12\x08\n\x04\x45LEC\x10\r\x12\t\n\x05SHARE\x10\x0e\x12\x0e\n\nSCREENSHOT\x10\x0f\x12\x0e\n\nLOCKSCREEN\x10\x10\x12\r\n\tRECOMMEND\x10\x11\x12\x11\n\rPLAYBACKSPEED\x10\x12\x12\x0e\n\nDEFINITION\x10\x13\x12\x0e\n\nSELECTIONS\x10\x14\x12\x08\n\x04NEXT\x10\x15\x12\n\n\x06\x45\x44ITDM\x10\x16\x12\x0f\n\x0bSMALLWINDOW\x10\x17\x12\t\n\x05SHAKE\x10\x18\x12\x0b\n\x07OUTERDM\x10\x19\x12\x0b\n\x07INNERDM\x10\x1a\x12\x0c\n\x08PANORAMA\x10\x1b\x12\t\n\x05\x44OLBY\x10\x1c\x12\x0f\n\x0b\x43OLORFILTER\x10\x1d*.\n\x05Group\x12\x10\n\x0cUnknownGroup\x10\x00\x12\x05\n\x01\x41\x10\x01\x12\x05\n\x01\x42\x10\x02\x12\x05\n\x01\x43\x10\x03*1\n\x07PlayErr\x12\t\n\x05NoErr\x10\x00\x12\x1b\n\x17WithMultiDeviceLoginErr\x10\x01*L\n\tVideoType\x12\x11\n\rUnknown_VALUE\x10\x00\x12\r\n\tFLV_VALUE\x10\x01\x12\x0e\n\nDASH_VALUE\x10\x02\x12\r\n\tMP4_VALUE\x10\x03\x32\xd1\x03\n\x07PlayURL\x12U\n\x07PlayURL\x12#.bilibili.app.playurl.v1.PlayURLReq\x1a%.bilibili.app.playurl.v1.PlayURLReply\x12U\n\x07Project\x12#.bilibili.app.playurl.v1.ProjectReq\x1a%.bilibili.app.playurl.v1.ProjectReply\x12X\n\x08PlayView\x12$.bilibili.app.playurl.v1.PlayViewReq\x1a&.bilibili.app.playurl.v1.PlayViewReply\x12\x64\n\x0cPlayConfEdit\x12(.bilibili.app.playurl.v1.PlayConfEditReq\x1a*.bilibili.app.playurl.v1.PlayConfEditReply\x12X\n\x08PlayConf\x12$.bilibili.app.playurl.v1.PlayConfReq\x1a&.bilibili.app.playurl.v1.PlayConfReplyb\x06proto3')

_BUSINESS = DESCRIPTOR.enum_types_by_name['Business']
Business = enum_type_wrapper.EnumTypeWrapper(_BUSINESS)
_CODETYPE = DESCRIPTOR.enum_types_by_name['CodeType']
CodeType = enum_type_wrapper.EnumTypeWrapper(_CODETYPE)
_CONFTYPE = DESCRIPTOR.enum_types_by_name['ConfType']
ConfType = enum_type_wrapper.EnumTypeWrapper(_CONFTYPE)
_GROUP = DESCRIPTOR.enum_types_by_name['Group']
Group = enum_type_wrapper.EnumTypeWrapper(_GROUP)
_PLAYERR = DESCRIPTOR.enum_types_by_name['PlayErr']
PlayErr = enum_type_wrapper.EnumTypeWrapper(_PLAYERR)
_VIDEOTYPE = DESCRIPTOR.enum_types_by_name['VideoType']
VideoType = enum_type_wrapper.EnumTypeWrapper(_VIDEOTYPE)
UNKNOWN = 0
STORY = 1
NOCODE = 0
CODE264 = 1
CODE265 = 2
NoType = 0
FLIPCONF = 1
CASTCONF = 2
FEEDBACK = 3
SUBTITLE = 4
PLAYBACKRATE = 5
TIMEUP = 6
PLAYBACKMODE = 7
SCALEMODE = 8
BACKGROUNDPLAY = 9
LIKE = 10
DISLIKE = 11
COIN = 12
ELEC = 13
SHARE = 14
SCREENSHOT = 15
LOCKSCREEN = 16
RECOMMEND = 17
PLAYBACKSPEED = 18
DEFINITION = 19
SELECTIONS = 20
NEXT = 21
EDITDM = 22
SMALLWINDOW = 23
SHAKE = 24
OUTERDM = 25
INNERDM = 26
PANORAMA = 27
DOLBY = 28
COLORFILTER = 29
UnknownGroup = 0
A = 1
B = 2
C = 3
NoErr = 0
WithMultiDeviceLoginErr = 1
Unknown_VALUE = 0
FLV_VALUE = 1
DASH_VALUE = 2
MP4_VALUE = 3


_AB = DESCRIPTOR.message_types_by_name['AB']
_ARCCONF = DESCRIPTOR.message_types_by_name['ArcConf']
_CHRONOS = DESCRIPTOR.message_types_by_name['Chronos']
_CLOUDCONF = DESCRIPTOR.message_types_by_name['CloudConf']
_CONFVALUE = DESCRIPTOR.message_types_by_name['ConfValue']
_DASHITEM = DESCRIPTOR.message_types_by_name['DashItem']
_DASHVIDEO = DESCRIPTOR.message_types_by_name['DashVideo']
_DOLBYITEM = DESCRIPTOR.message_types_by_name['DolbyItem']
_EVENT = DESCRIPTOR.message_types_by_name['Event']
_EXTRACONTENT = DESCRIPTOR.message_types_by_name['ExtraContent']
_FIELDVALUE = DESCRIPTOR.message_types_by_name['FieldValue']
_FORMATDESCRIPTION = DESCRIPTOR.message_types_by_name['FormatDescription']
_GLANCE = DESCRIPTOR.message_types_by_name['Glance']
_PLAYABILITYCONF = DESCRIPTOR.message_types_by_name['PlayAbilityConf']
_PLAYARCCONF = DESCRIPTOR.message_types_by_name['PlayArcConf']
_PLAYCONFEDITREPLY = DESCRIPTOR.message_types_by_name['PlayConfEditReply']
_PLAYCONFEDITREQ = DESCRIPTOR.message_types_by_name['PlayConfEditReq']
_PLAYCONFREPLY = DESCRIPTOR.message_types_by_name['PlayConfReply']
_PLAYCONFREQ = DESCRIPTOR.message_types_by_name['PlayConfReq']
_PLAYCONFSTATE = DESCRIPTOR.message_types_by_name['PlayConfState']
_PLAYURLREPLY = DESCRIPTOR.message_types_by_name['PlayURLReply']
_PLAYURLREQ = DESCRIPTOR.message_types_by_name['PlayURLReq']
_PLAYVIEWREPLY = DESCRIPTOR.message_types_by_name['PlayViewReply']
_PLAYVIEWREQ = DESCRIPTOR.message_types_by_name['PlayViewReq']
_PROJECTREPLY = DESCRIPTOR.message_types_by_name['ProjectReply']
_PROJECTREQ = DESCRIPTOR.message_types_by_name['ProjectReq']
_RESPONSEDASH = DESCRIPTOR.message_types_by_name['ResponseDash']
_RESPONSEURL = DESCRIPTOR.message_types_by_name['ResponseUrl']
_SEGMENTVIDEO = DESCRIPTOR.message_types_by_name['SegmentVideo']
_SHAKE = DESCRIPTOR.message_types_by_name['Shake']
_STREAM = DESCRIPTOR.message_types_by_name['Stream']
_STREAMINFO = DESCRIPTOR.message_types_by_name['StreamInfo']
_STREAMLIMIT = DESCRIPTOR.message_types_by_name['StreamLimit']
_UPGRADEBUTTON = DESCRIPTOR.message_types_by_name['UpgradeButton']
_UPGRADELIMIT = DESCRIPTOR.message_types_by_name['UpgradeLimit']
_VIDEOINFO = DESCRIPTOR.message_types_by_name['VideoInfo']
_VOLUMEINFO = DESCRIPTOR.message_types_by_name['VolumeInfo']
_DOLBYITEM_TYPE = _DOLBYITEM.enum_types_by_name['Type']
AB = _reflection.GeneratedProtocolMessageType('AB', (_message.Message,), {
  'DESCRIPTOR' : _AB,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.AB)
  })
_sym_db.RegisterMessage(AB)

ArcConf = _reflection.GeneratedProtocolMessageType('ArcConf', (_message.Message,), {
  'DESCRIPTOR' : _ARCCONF,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ArcConf)
  })
_sym_db.RegisterMessage(ArcConf)

Chronos = _reflection.GeneratedProtocolMessageType('Chronos', (_message.Message,), {
  'DESCRIPTOR' : _CHRONOS,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.Chronos)
  })
_sym_db.RegisterMessage(Chronos)

CloudConf = _reflection.GeneratedProtocolMessageType('CloudConf', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDCONF,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.CloudConf)
  })
_sym_db.RegisterMessage(CloudConf)

ConfValue = _reflection.GeneratedProtocolMessageType('ConfValue', (_message.Message,), {
  'DESCRIPTOR' : _CONFVALUE,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ConfValue)
  })
_sym_db.RegisterMessage(ConfValue)

DashItem = _reflection.GeneratedProtocolMessageType('DashItem', (_message.Message,), {
  'DESCRIPTOR' : _DASHITEM,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.DashItem)
  })
_sym_db.RegisterMessage(DashItem)

DashVideo = _reflection.GeneratedProtocolMessageType('DashVideo', (_message.Message,), {
  'DESCRIPTOR' : _DASHVIDEO,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.DashVideo)
  })
_sym_db.RegisterMessage(DashVideo)

DolbyItem = _reflection.GeneratedProtocolMessageType('DolbyItem', (_message.Message,), {
  'DESCRIPTOR' : _DOLBYITEM,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.DolbyItem)
  })
_sym_db.RegisterMessage(DolbyItem)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.Event)
  })
_sym_db.RegisterMessage(Event)

ExtraContent = _reflection.GeneratedProtocolMessageType('ExtraContent', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACONTENT,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ExtraContent)
  })
_sym_db.RegisterMessage(ExtraContent)

FieldValue = _reflection.GeneratedProtocolMessageType('FieldValue', (_message.Message,), {
  'DESCRIPTOR' : _FIELDVALUE,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.FieldValue)
  })
_sym_db.RegisterMessage(FieldValue)

FormatDescription = _reflection.GeneratedProtocolMessageType('FormatDescription', (_message.Message,), {
  'DESCRIPTOR' : _FORMATDESCRIPTION,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.FormatDescription)
  })
_sym_db.RegisterMessage(FormatDescription)

Glance = _reflection.GeneratedProtocolMessageType('Glance', (_message.Message,), {
  'DESCRIPTOR' : _GLANCE,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.Glance)
  })
_sym_db.RegisterMessage(Glance)

PlayAbilityConf = _reflection.GeneratedProtocolMessageType('PlayAbilityConf', (_message.Message,), {
  'DESCRIPTOR' : _PLAYABILITYCONF,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayAbilityConf)
  })
_sym_db.RegisterMessage(PlayAbilityConf)

PlayArcConf = _reflection.GeneratedProtocolMessageType('PlayArcConf', (_message.Message,), {
  'DESCRIPTOR' : _PLAYARCCONF,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayArcConf)
  })
_sym_db.RegisterMessage(PlayArcConf)

PlayConfEditReply = _reflection.GeneratedProtocolMessageType('PlayConfEditReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYCONFEDITREPLY,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayConfEditReply)
  })
_sym_db.RegisterMessage(PlayConfEditReply)

PlayConfEditReq = _reflection.GeneratedProtocolMessageType('PlayConfEditReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYCONFEDITREQ,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayConfEditReq)
  })
_sym_db.RegisterMessage(PlayConfEditReq)

PlayConfReply = _reflection.GeneratedProtocolMessageType('PlayConfReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYCONFREPLY,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayConfReply)
  })
_sym_db.RegisterMessage(PlayConfReply)

PlayConfReq = _reflection.GeneratedProtocolMessageType('PlayConfReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYCONFREQ,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayConfReq)
  })
_sym_db.RegisterMessage(PlayConfReq)

PlayConfState = _reflection.GeneratedProtocolMessageType('PlayConfState', (_message.Message,), {
  'DESCRIPTOR' : _PLAYCONFSTATE,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayConfState)
  })
_sym_db.RegisterMessage(PlayConfState)

PlayURLReply = _reflection.GeneratedProtocolMessageType('PlayURLReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURLREPLY,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayURLReply)
  })
_sym_db.RegisterMessage(PlayURLReply)

PlayURLReq = _reflection.GeneratedProtocolMessageType('PlayURLReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURLREQ,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayURLReq)
  })
_sym_db.RegisterMessage(PlayURLReq)

PlayViewReply = _reflection.GeneratedProtocolMessageType('PlayViewReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREPLY,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayViewReply)
  })
_sym_db.RegisterMessage(PlayViewReply)

PlayViewReq = _reflection.GeneratedProtocolMessageType('PlayViewReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREQ,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.PlayViewReq)
  })
_sym_db.RegisterMessage(PlayViewReq)

ProjectReply = _reflection.GeneratedProtocolMessageType('ProjectReply', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREPLY,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ProjectReply)
  })
_sym_db.RegisterMessage(ProjectReply)

ProjectReq = _reflection.GeneratedProtocolMessageType('ProjectReq', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREQ,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ProjectReq)
  })
_sym_db.RegisterMessage(ProjectReq)

ResponseDash = _reflection.GeneratedProtocolMessageType('ResponseDash', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDASH,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ResponseDash)
  })
_sym_db.RegisterMessage(ResponseDash)

ResponseUrl = _reflection.GeneratedProtocolMessageType('ResponseUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEURL,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.ResponseUrl)
  })
_sym_db.RegisterMessage(ResponseUrl)

SegmentVideo = _reflection.GeneratedProtocolMessageType('SegmentVideo', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTVIDEO,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.SegmentVideo)
  })
_sym_db.RegisterMessage(SegmentVideo)

Shake = _reflection.GeneratedProtocolMessageType('Shake', (_message.Message,), {
  'DESCRIPTOR' : _SHAKE,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.Shake)
  })
_sym_db.RegisterMessage(Shake)

Stream = _reflection.GeneratedProtocolMessageType('Stream', (_message.Message,), {
  'DESCRIPTOR' : _STREAM,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.Stream)
  })
_sym_db.RegisterMessage(Stream)

StreamInfo = _reflection.GeneratedProtocolMessageType('StreamInfo', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINFO,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.StreamInfo)
  })
_sym_db.RegisterMessage(StreamInfo)

StreamLimit = _reflection.GeneratedProtocolMessageType('StreamLimit', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLIMIT,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.StreamLimit)
  })
_sym_db.RegisterMessage(StreamLimit)

UpgradeButton = _reflection.GeneratedProtocolMessageType('UpgradeButton', (_message.Message,), {
  'DESCRIPTOR' : _UPGRADEBUTTON,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.UpgradeButton)
  })
_sym_db.RegisterMessage(UpgradeButton)

UpgradeLimit = _reflection.GeneratedProtocolMessageType('UpgradeLimit', (_message.Message,), {
  'DESCRIPTOR' : _UPGRADELIMIT,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.UpgradeLimit)
  })
_sym_db.RegisterMessage(UpgradeLimit)

VideoInfo = _reflection.GeneratedProtocolMessageType('VideoInfo', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOINFO,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.VideoInfo)
  })
_sym_db.RegisterMessage(VideoInfo)

VolumeInfo = _reflection.GeneratedProtocolMessageType('VolumeInfo', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMEINFO,
  '__module__' : 'bilibili.app.playurl.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.playurl.v1.VolumeInfo)
  })
_sym_db.RegisterMessage(VolumeInfo)

_PLAYURL = DESCRIPTOR.services_by_name['PlayURL']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUSINESS._serialized_start=8437
  _BUSINESS._serialized_end=8471
  _CODETYPE._serialized_start=8473
  _CODETYPE._serialized_end=8521
  _CONFTYPE._serialized_start=8524
  _CONFTYPE._serialized_end=8955
  _GROUP._serialized_start=8957
  _GROUP._serialized_end=9003
  _PLAYERR._serialized_start=9005
  _PLAYERR._serialized_end=9054
  _VIDEOTYPE._serialized_start=9056
  _VIDEOTYPE._serialized_end=9132
  _AB._serialized_start=66
  _AB._serialized_end=134
  _ARCCONF._serialized_start=136
  _ARCCONF._serialized_end=245
  _CHRONOS._serialized_start=247
  _CHRONOS._serialized_end=283
  _CLOUDCONF._serialized_start=286
  _CLOUDCONF._serialized_end=479
  _CONFVALUE._serialized_start=481
  _CONFVALUE._serialized_end=547
  _DASHITEM._serialized_start=550
  _DASHITEM._serialized_end=692
  _DASHVIDEO._serialized_start=695
  _DASHVIDEO._serialized_end=895
  _DOLBYITEM._serialized_start=898
  _DOLBYITEM._serialized_end=1055
  _DOLBYITEM_TYPE._serialized_start=1016
  _DOLBYITEM_TYPE._serialized_end=1055
  _EVENT._serialized_start=1057
  _EVENT._serialized_end=1111
  _EXTRACONTENT._serialized_start=1113
  _EXTRACONTENT._serialized_end=1175
  _FIELDVALUE._serialized_start=1177
  _FIELDVALUE._serialized_end=1216
  _FORMATDESCRIPTION._serialized_start=1219
  _FORMATDESCRIPTION._serialized_end=1360
  _GLANCE._serialized_start=1362
  _GLANCE._serialized_end=1422
  _PLAYABILITYCONF._serialized_start=1425
  _PLAYABILITYCONF._serialized_end=3162
  _PLAYARCCONF._serialized_start=3165
  _PLAYARCCONF._serialized_end=4904
  _PLAYCONFEDITREPLY._serialized_start=4906
  _PLAYCONFEDITREPLY._serialized_end=4925
  _PLAYCONFEDITREQ._serialized_start=4927
  _PLAYCONFEDITREQ._serialized_end=5003
  _PLAYCONFREPLY._serialized_start=5005
  _PLAYCONFREPLY._serialized_end=5081
  _PLAYCONFREQ._serialized_start=5083
  _PLAYCONFREQ._serialized_end=5096
  _PLAYCONFSTATE._serialized_start=5099
  _PLAYCONFSTATE._serialized_end=5296
  _PLAYURLREPLY._serialized_start=5299
  _PLAYURLREPLY._serialized_end=5748
  _PLAYURLREQ._serialized_start=5751
  _PLAYURLREQ._serialized_end=5919
  _PLAYVIEWREPLY._serialized_start=5922
  _PLAYVIEWREPLY._serialized_end=6311
  _PLAYVIEWREQ._serialized_start=6314
  _PLAYVIEWREQ._serialized_end=6645
  _PROJECTREPLY._serialized_start=6647
  _PROJECTREPLY._serialized_end=6717
  _PROJECTREQ._serialized_start=6720
  _PROJECTREQ._serialized_end=6927
  _RESPONSEDASH._serialized_start=6929
  _RESPONSEDASH._serialized_end=7043
  _RESPONSEURL._serialized_start=7045
  _RESPONSEURL._serialized_end=7149
  _SEGMENTVIDEO._serialized_start=7151
  _SEGMENTVIDEO._serialized_end=7220
  _SHAKE._serialized_start=7222
  _SHAKE._serialized_end=7243
  _STREAM._serialized_start=7246
  _STREAM._serialized_end=7445
  _STREAMINFO._serialized_start=7448
  _STREAMINFO._serialized_end=7746
  _STREAMLIMIT._serialized_start=7748
  _STREAMLIMIT._serialized_end=7802
  _UPGRADEBUTTON._serialized_start=7804
  _UPGRADEBUTTON._serialized_end=7848
  _UPGRADELIMIT._serialized_start=7850
  _UPGRADELIMIT._serialized_end=7966
  _VIDEOINFO._serialized_start=7969
  _VIDEOINFO._serialized_end=8269
  _VOLUMEINFO._serialized_start=8272
  _VOLUMEINFO._serialized_end=8435
  _PLAYURL._serialized_start=9135
  _PLAYURL._serialized_end=9600
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CheckAccountReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_NEW_FIELD_NUMBER: builtins.int
    is_new: builtins.bool
    """"""

    def __init__(self,
        *,
        is_new: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_new",b"is_new"]) -> None: ...
global___CheckAccountReply = CheckAccountReply

class CheckAccountReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    PERIODS_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""

    periods: typing.Text
    """"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        periods: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["periods",b"periods","uid",b"uid"]) -> None: ...
global___CheckAccountReq = CheckAccountReq

class FavoriteTabItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    uri: typing.Text
    """"""

    type: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        uri: typing.Text = ...,
        type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","type",b"type","uri",b"uri"]) -> None: ...
global___FavoriteTabItem = FavoriteTabItem

class FavoriteTabReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavoriteTabItem]:
        """"""
        pass
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___FavoriteTabItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items"]) -> None: ...
global___FavoriteTabReply = FavoriteTabReply

class FavoriteTabReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___FavoriteTabReq = FavoriteTabReq
